@@ -1,9 +1,8 @@
 skip_if_not_installed("boot")
 
 test_that(
-  desc = "centrality description works as expected",
+  desc = "centrality description works as expected - no missing data",
   code = {
-    # data without NAs
     set.seed(123)
     df <- purrr::pmap_dfr(
       .l = list(
@@ -20,8 +19,15 @@ test_that(
     set.seed(123)
     expect_snapshot(select(df, -expression))
     expect_snapshot(df[["expression"]])
+  }
+)
+
+test_that(
+  desc = "centrality description works as expected - missing data",
+  code = {
+    # some MAP estimates are different on macOS compared to windows and linux
+    skip_on_os(c("windows", "linux"))
 
-    # data with NAs
     set.seed(123)
     df_na <- purrr::pmap_dfr(
       .l = list(
