@@ -2,8 +2,6 @@
 # Bayesian meta-analysis often crashes R session on macOS
 # this makes sure this test will be run after all others
 
-
-
 test_that(
   desc = "meta_analysis works - bayesian",
   code = {
@@ -11,7 +9,7 @@ test_that(
     skip_if_not_installed("metaplus")
 
     data(mag, package = "metaplus")
-    dat <- mag %>% rename(estimate = yi, std.error = sei)
+    dat <- dplyr::rename(mag, estimate = yi, std.error = sei)
 
     set.seed(123)
     df <- suppressWarnings(meta_analysis(
